[Zope-CVS] CVS: Products/AdaptableStorage/serial/interfaces - IKeyedObjectSystem.py:1.5

Shane Hathaway shane@zope.com
Mon, 16 Dec 2002 18:27:12 -0500


Update of /cvs-repository/Products/AdaptableStorage/serial/interfaces
In directory cvs.zope.org:/tmp/cvs-serv25263/serial/interfaces

Modified Files:
	IKeyedObjectSystem.py 
Log Message:
- loadStub() now expects "hints" that help it avoid loading the entire object
into memory.  mapper_names is a good hint, but frequently unknown to the
application.

- Added modifiedInVersion() to UnmanagedJar, since PersistentExtra expects to
find it.


=== Products/AdaptableStorage/serial/interfaces/IKeyedObjectSystem.py 1.4 => 1.5 ===
--- Products/AdaptableStorage/serial/interfaces/IKeyedObjectSystem.py:1.4	Mon Dec  9 10:57:24 2002
+++ Products/AdaptableStorage/serial/interfaces/IKeyedObjectSystem.py	Mon Dec 16 18:26:41 2002
@@ -21,12 +21,18 @@
 class IKeyedObjectSystem (Interface):
     """A collection of objects identifiable by keychain."""
 
-    def loadStub(keychain, mapper_names=None):
+    def loadStub(keychain, hints=None):
         """Returns a class instance, possibly ghosted.
 
-        mapper_names is provided as a possible optimization.  Without
-        it, this method may have to load a full object rather than a
-        ghosted object.
+        hints, a mapping, may be provided as an optimization.
+        Without it, implementations of this method may have to load a
+        full object rather than a ghosted object.
+
+        Some hints may be:
+
+        classification
+        mapper_name (the mapper name for the last item in the keychain)
+        mapper_names (a list of all mapper names)
         """
 
     def identifyObject(object):